"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConnectionRequestHandler = void 0;
const helpers_1 = require("../../../agent/helpers");
const error_1 = require("../../../error");
const messages_1 = require("../messages");
class ConnectionRequestHandler {
    constructor(connectionService, agentConfig, mediationRecipientService) {
        this.supportedMessages = [messages_1.ConnectionRequestMessage];
        this.connectionService = connectionService;
        this.agentConfig = agentConfig;
        this.mediationRecipientService = mediationRecipientService;
    }
    async handle(messageContext) {
        var _a;
        if (!messageContext.connection) {
            throw new error_1.AriesFrameworkError(`Connection for verkey ${messageContext.recipientVerkey} not found!`);
        }
        let routing;
        // routing object is required for multi use invitation, because we're creating a
        // new keypair that possibly needs to be registered at a mediator
        if (messageContext.connection.multiUseInvitation) {
            const mediationRecord = await this.mediationRecipientService.discoverMediation();
            routing = await this.mediationRecipientService.getRouting(mediationRecord);
        }
        const connection = await this.connectionService.processRequest(messageContext, routing);
        if ((_a = connection === null || connection === void 0 ? void 0 : connection.autoAcceptConnection) !== null && _a !== void 0 ? _a : this.agentConfig.autoAcceptConnections) {
            const { message } = await this.connectionService.createResponse(connection.id);
            return helpers_1.createOutboundMessage(connection, message);
        }
    }
}
exports.ConnectionRequestHandler = ConnectionRequestHandler;
//# sourceMappingURL=ConnectionRequestHandler.js.map